Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
v2.0
Breaking changes. Both L* and KV signatures have changed, requiring passing fuel in via the Teacher module rather than upon calling the learner loop. This arises from new guarantees about termination and minimality for both algorithms.